@@ -1,15 +1,15 @@
 import numpy as np
 from sklearn.metrics import confusion_matrix
+
 # from .model.EventManager import EventManager
 
 
 class Scorer:
     title = "Segmentbasiert"
     cmScaleByClass = 4
-    
-    metricNameMap = {
-    }
-    
+
+    metricNameMap = {}
+
     def getMetricName(self, metricName):
         if metricName in Scorer.metricNameMap:
             metricName = Scorer.metricNameMap[metricName]
@@ -39,16 +39,16 @@ class Scorer:
         # for classification task the shape can be (recordcount?, predictions, classCount)
         isOneHotEncode = inputArray.shape[-1] == self.numClasses
         return inputArray.reshape(-1, self.numClasses) if isOneHotEncode else inputArray.reshape(-1)
-    
+
     def prepareTruth(self, inputArray):
         """flatten and squeeze the truth array"""
         isOneHotEncode = inputArray.shape[-1] == self.numClasses
-        
+
         if isOneHotEncode:
             maskedIgnored = inputArray.sum(axis=-1) == 0
             inputArray = np.argmax(inputArray, axis=-1)
             inputArray[maskedIgnored] = -1
-        
+
         return inputArray.reshape(-1)
 
     def score(self, truth, prediction, recordName=None, trace=True):
@@ -89,9 +89,10 @@ class Scorer:
     def getRecords(self):
 
         return self.recordResult.values()
-        
+
     def getRecordsAsDataframe(self):
         import pandas as pd
+
         return pd.DataFrame(
             self.getRecords(),
             index=list(self.recordResult.keys()),
@@ -100,7 +101,7 @@ class Scorer:
     def combineMetric(self, metricName):
 
         metricName = self.getMetricName(metricName)
-        
+
         result = None
         if metricName in ["kappa", "accuracy"]:  # recalcuate from confusion
             self.combineMetric("confusion")
@@ -202,7 +203,7 @@ class Scorer:
         return k, acc
 
     def maskArgMax(self, a, threshold):
-        masked = np.ma.MaskedArray(a, a<threshold)
+        masked = np.ma.MaskedArray(a, a < threshold)
         return np.ma.argmax(masked)
 
     def getClassLikelyhood(self, prediction):
@@ -217,12 +218,11 @@ class Scorer:
         return classLikelyhood
 
     def getClassPrediction(self, prediction):
-        likelyhood =  self.getClassLikelyhood(prediction)
+        likelyhood = self.getClassLikelyhood(prediction)
         prediction = np.full(prediction.shape[0], 0)
         prediction[likelyhood > self.threshold] = 1
         return prediction
 
-
     def flattenPrediction(self, prediction, binaryLikelyHood=False, threshold=None):
         if binaryLikelyHood and self.numClasses != 2:
             raise Exception("Selected metric only support binary classification at the moment")
@@ -233,24 +233,25 @@ class Scorer:
         if self.isHotEncoded(prediction):
             prediction = prediction.argmax(-1)
         else:
-            threshhold = 0.5 if self.threshold is None else self.threshold 
+            threshhold = 0.5 if self.threshold is None else self.threshold
             prediction[prediction >= threshhold] = 1
             prediction[prediction < threshhold] = 0
         return prediction
-    
+
     def getMetricScorer(self, metricName):
         def score(truth, prediction):
             prediction = self.preparePrediction(prediction)
             truth = self.prepareTruth(truth)
             self.results = {}
             return self.scoreMetric(metricName, truth, prediction)
+
         score.__name__ = metricName
         return score
 
     def scoreMetric(self, metricName, truth, prediction):
-        
+
         metricName = self.getMetricName(metricName)
-        
+
         if metricName in self.results:
             return self.results[metricName]
 
@@ -268,7 +269,7 @@ class Scorer:
         elif metricName in ["auprc", "auroc"]:
             classLikelyhood = self.getClassLikelyhood(prediction)
 
-            scale = 10**3
+            scale = 10 ** 3
             b = scale + 1
             r = (-0.5 / scale, 1.0 + 0.5 / scale)
 
@@ -331,13 +332,13 @@ class Scorer:
             tn = confusion[0][0]
             f = np.sum(confusion) - tp - tn
             self.results[metricName] = tp / (tp + f)
-        elif metricName == "SNR": # signal to noise ratio
+        elif metricName == "SNR":  # signal to noise ratio
             axis = 0
             ddof = 0
             a = np.asanyarray(prediction)
             m = a.mean(axis)
             sd = a.std(axis=axis, ddof=ddof)
-            self.results[metricName] = np.where(sd == 0, 0, m/sd)
+            self.results[metricName] = np.where(sd == 0, 0, m / sd)
         elif metricName == "fm":  # Fowlkes–Mallows index
             confusion = self.scoreMetric("confusion", truth, prediction)
             (tn, fp), (fn, tp) = confusion
@@ -356,7 +357,7 @@ class Scorer:
     def getValuesFromClasses(self):
         if self.possibleValues is None:
             values = []
-            for id in range(self.numClasses**2):
+            for id in range(self.numClasses ** 2):
                 trueValue, preditedValue = (id // self.numClasses, id % self.numClasses)
                 values.append("%s as %s" % (self.classNames[trueValue], self.classNames[preditedValue]))
             self.possibleValues = values
@@ -456,7 +457,13 @@ class Scorer:
         tnr = 0
         if tp == 0 or fp == 0:
             # If either class is empty, scores are undefined.
-            return (float("nan"), float("nan"), float("nan"), float("nan"), float("nan"))
+            return (
+                float("nan"),
+                float("nan"),
+                float("nan"),
+                float("nan"),
+                float("nan"),
+            )
         ppv = float(tp) / (tp + fp)
         auroc = []
         auprc = []
